"""
Version as of November 18, 2020.

This module is work in progress.

For bug reports/suggestions/correspondence, please
reach out to us at tauro_henson@lilly.com and
gabbanini_francesco@lilly.com
"""

__version__ = '1.0.2post1'